* Re: [PATCH 0/5] bridge patchs
From: David Miller @ 2011-07-23 0:15 UTC (permalink / raw)
To: shemminger; +Cc: davem, netdev
In-Reply-To: <20110722174705.144993799@vyatta.com>
From: Stephen Hemminger <shemminger@vyatta.com>
Date: Fri, 22 Jul 2011 10:47:05 -0700
> Bridge patches. These are order by urgency from important to trivial.
All applied.
^ permalink raw reply
* Re: [PATCH] dm9000: Make the driver follow the IRQF_SHARED contract
From: David Miller @ 2011-07-23 0:15 UTC (permalink / raw)
To: daniel.morsing; +Cc: broonie, netdev, linux-kernel
In-Reply-To: <1311357162-16200-1-git-send-email-daniel.morsing@gmail.com>
From: Daniel Morsing <daniel.morsing@gmail.com>
Date: Fri, 22 Jul 2011 19:52:42 +0200
> The dm9000 driver requests a shared interrupt but doesn't return
> IRQ_NONE when the device didn't generate the interrupt. This could lead
> to the other devices sharing the irq never getting an interrupt. This
> patch makes the routine return IRQ_NONE for the path where no work was
> done.
>
> Signed-off-by: Daniel Morsing <daniel.morsing@gmail.com>
> Cc: stable@kernel.org
Applied.
^ permalink raw reply
* Re: pull request: wireless-next-2.6 2011-07-22
From: David Miller @ 2011-07-23 0:16 UTC (permalink / raw)
To: linville; +Cc: linux-wireless, netdev, linux-kernel
In-Reply-To: <20110722222308.GA3048@tuxdriver.com>
From: "John W. Linville" <linville@tuxdriver.com>
Date: Fri, 22 Jul 2011 18:23:09 -0400
> Here is the last big pull request of new wireless bits intended
> for 3.1. This includes the usual big batch of updates to iwlagn,
> a number of updates to ath9k, mwifiex, carl9170, libertas, and other
> drivers, and soem updates to mac80211 and cfg80211 from Johannes.
> The most noteworth bits are most of the final push from Rafał for
> supporting current Broadcom wireless hardware in b43.
>
> Please let me know if there are problems!
A little late to be submitting this since the merge window is
already open, but I pulled anyways.
Thanks!
^ permalink raw reply
* Re: [PATCH 00/10] bna: driver fixes and cleanup
From: David Miller @ 2011-07-23 0:15 UTC (permalink / raw)
To: rmody; +Cc: netdev, adapter_linux_open_src_team
In-Reply-To: <1311358069-32067-1-git-send-email-rmody@brocade.com>
From: Rasesh Mody <rmody@brocade.com>
Date: Fri, 22 Jul 2011 11:07:39 -0700
> The following patch set adds fixes and clean ups for current upstream driver.
>
> The driver has been compiled and tested against net-next-2.6(3.0.0-rc7)
All applied.
^ permalink raw reply
* Re: [PATCH] net: allow netif_carrier to be called safely from IRQ
From: David Miller @ 2011-07-23 0:16 UTC (permalink / raw)
To: shemminger; +Cc: romieu, greearb, torvalds, david, tj, linux-kernel, netdev
In-Reply-To: <20110722155356.5911225f@nehalam.ftrdhcpuser.net>
From: Stephen Hemminger <shemminger@vyatta.com>
Date: Fri, 22 Jul 2011 15:53:56 -0700
> As reported by Ben Greer and Froncois Romieu. The code path in
> the netif_carrier code leads it to try and disable
> a late workqueue to reenable it immediately
> netif_carrier_on
> -> linkwatch_fire_event
> -> linkwatch_schedule_work
> -> cancel_delayed_work
> -> del_timer_sync
>
> If __cancel_delayed_work is used instead then there is no
> problem of waiting for running linkwatch_event.
>
> There is a race between linkwatch_event running re-scheduling
> but it is harmless to schedule an extra scan of the linkwatch queue.
>
> Signed-off-by: Stephen Hemminger <shemminger@vyatta.com>
Applied.
^ permalink raw reply
* Re: Linux 3.0 release
From: Tejun Heo @ 2011-07-23 2:27 UTC (permalink / raw)
To: Linus Torvalds
Cc: Stephen Hemminger, Ben Greear, David, Linux Kernel Mailing List,
netdev
In-Reply-To: <CA+55aFwX55HhzyPsb5vx-=xkHpWJBH0481ZFWcXnNzH1M6zhdg@mail.gmail.com>
Hello, Stephen, Linus.
On Fri, Jul 22, 2011 at 01:35:16PM -0700, Linus Torvalds wrote:
> On Fri, Jul 22, 2011 at 1:32 PM, Stephen Hemminger
> <shemminger@vyatta.com> wrote:
> >
> > The workqueue code should have a fallback and not try and
> > do anything if being called from IRQ.
>
> Fair enough. Especially since one of the *points* of workqueues is
> indeed to schedule stuff from irqs and that cannot be done
> immediately.
>
> Tejun?
It seems to have been already tracked down but, just to be clear.
Nothing changed regarding synchronization requirements for all the
queue, flush and cancel functions. If it worked before cmwq, it
should work with cmwq.
While on the topic, we do have some workqueue API problems. The
delayed ones are a bit screwy. e.g. requeueing an already pending
delayed work item should probably update the timer but it doesn't andp
we have a bunch of users doing cancel/requeue or using separate timers
for that. Also, the cancel/flush[_sync] variants are subtly different
making using the correct one difficult, which has possibility of
introducing bugs which are extremely difficult to reproduce.
Again, most of these had accumulated well before cmwq came into the
picture. I think we need to make workqueue simpler and easier to use.
Thanks.
--
tejun
^ permalink raw reply
* Re: Linux 3.0 release
From: Tejun Heo @ 2011-07-23 2:30 UTC (permalink / raw)
To: Linus Torvalds
Cc: Stephen Hemminger, Ben Greear, David, Linux Kernel Mailing List,
netdev
In-Reply-To: <20110723022715.GB21089@mtj.dyndns.org>
On Sat, Jul 23, 2011 at 04:27:15AM +0200, Tejun Heo wrote:
> While on the topic, we do have some workqueue API problems. The
> delayed ones are a bit screwy. e.g. requeueing an already pending
> delayed work item should probably update the timer but it doesn't andp
> we have a bunch of users doing cancel/requeue or using separate timers
> for that.
(after reading the other branch of the thread) Ooh, bingo, this
actually was the issue which triggered the problem reported here. :)
--
tejun
^ permalink raw reply
* Re: [PATCH] net: Fix security_socket_sendmsg() bypass problem.
From: Tetsuo Handa @ 2011-07-23 5:20 UTC (permalink / raw)
To: davem; +Cc: casey, anton, netdev, linux-security-module
In-Reply-To: <201107230331.GHE48423.QFHJMFOLtOOSVF@I-love.SAKURA.ne.jp>
Tetsuo Handa wrote:
> Tetsuo Handa wrote:
> > David Miller wrote:
> > > Ugh, this takes away a non-trivial part of the performance gain of
> > > sendmmsg().
> > >
> > > I would instead rather that you check ahead of time whether this
> > > actually is a send to different addresses. If they are all the
> > > same, keep the nosec code path.
> > >
> > OK. Something like this? Not tested at all.
>
> No. We can't compare destination address before entering __sys_sendmsg(), for
> it is copied to kernel memory by verify_iovec()/verify_compat_iovec().
>
OK. Something like this? Not tested at all.
----------------------------------------
[PATCH] net: Fix security_socket_sendmsg() bypass problem.
The sendmmsg() introduced by commit 228e548e "net: Add sendmmsg socket system
call" is capable of sending to multiple different destinations. However,
security_socket_sendmsg() is called for only once even if multiple different
destination's addresses are passed to sendmmsg().
SMACK is using destination's address for checking sendmsg() permission.
Therefore, we need to call security_socket_sendmsg() for each destination
address rather than the first destination address.
Fix this problem by maintaining a list of already-checked destination address.
Signed-off-by: Tetsuo Handa <penguin-kernel@I-love.SAKURA.ne.jp>
Cc: stable <stable@kernel.org> [3.0+]
---
net/socket.c | 84 +++++++++++++++++++++++++++++++++++++++++++++++++++++++----
1 file changed, 79 insertions(+), 5 deletions(-)
diff --git a/net/ipv4/gre.c b/net/ipv4/gre.c
index 9dbe108..dbfc21d 100644
--- a/net/ipv4/gre.c
+++ b/net/ipv4/gre.c
@@ -15,6 +15,7 @@
#include <linux/kmod.h>
#include <linux/skbuff.h>
#include <linux/in.h>
+#include <linux/ip.h>
#include <linux/netdevice.h>
#include <linux/spinlock.h>
#include <net/protocol.h>
@@ -96,27 +97,17 @@ drop:
static void gre_err(struct sk_buff *skb, u32 info)
{
const struct gre_protocol *proto;
- u8 ver;
-
- if (!pskb_may_pull(skb, 12))
- goto drop;
+ const struct iphdr *iph = (const struct iphdr *)skb->data;
+ u8 ver = skb->data[(iph->ihl<<2) + 1]&0x7f;
- ver = skb->data[1]&0x7f;
if (ver >= GREPROTO_MAX)
- goto drop;
+ return;
rcu_read_lock();
proto = rcu_dereference(gre_proto[ver]);
- if (!proto || !proto->err_handler)
- goto drop_unlock;
- proto->err_handler(skb, info);
- rcu_read_unlock();
- return;
-
-drop_unlock:
+ if (proto && proto->err_handler)
+ proto->err_handler(skb, info);
rcu_read_unlock();
-drop:
- kfree_skb(skb);
}
static const struct net_protocol net_gre_protocol = {
^ permalink raw reply related
* Re: [PATCH] net: Fix security_socket_sendmsg() bypass problem.
From: Michael Tokarev @ 2011-07-23 7:04 UTC (permalink / raw)
To: David Miller; +Cc: penguin-kernel, casey, anton, netdev, linux-security-module
In-Reply-To: <20110722.082224.688620059032914637.davem@davemloft.net>
22.07.2011 19:22, David Miller wrote:
> From: Tetsuo Handa <penguin-kernel@I-love.SAKURA.ne.jp>
> Date: Sat, 23 Jul 2011 00:12:53 +0900
>
>> I think the regression for SMACK can be fixed with below patch.
>>
>> Should I pass nosec flags down to "struct security_operations"->sendmsg()
>> so that SELinux checks sock_has_perm() for only once when multiple different
>> destination's addresses are passed to sendmmsg()?
>>
>> static int selinux_socket_sendmsg(struct socket *sock, struct msghdr *msg,
>> int size, int nosec)
>> {
>> return nosec ? 0 : sock_has_perm(current, sock->sk, SOCKET__WRITE);
>> }
>
> Ugh, this takes away a non-trivial part of the performance gain of
> sendmmsg().
>
> I would instead rather that you check ahead of time whether this
> actually is a send to different addresses. If they are all the
> same, keep the nosec code path.
Why to optimize for this case when destination addresses are the
same? How common this usage case is, or even where it _can_
happen alot (I noticed samba.org address in the Cc list).
When I saw recvmmsg()/sendmmsg() here, my first thought was an
authoritative DNS server which can read several requests at a
time and answer them all at once too - this way it all will go
to different addresses.
I understand the initial change takes away good portion of
performance improvement, but I think the optimisation should
be performed in a different place than for a not-so-common
cenario.
Thanks,
/mjt
^ permalink raw reply
* Re: [ath9k-devel] [PATCH] ath9k: use pci_dev->subsystem_device
From: Pavel Roskin @ 2011-07-23 7:53 UTC (permalink / raw)
To: Sergei Shtylyov
Cc: netdev-u79uwXL29TY76Z2rM5mHXA, linville-2XuSBdqkA4R54TAoqtyWWQ,
linux-wireless-u79uwXL29TY76Z2rM5mHXA,
ath9k-devel-xDcbHBWguxHbcTqmT+pZeQ,
senthilkumar-DlyHzToyqoxBDgjK7y7TUQ,
vasanth-DlyHzToyqoxBDgjK7y7TUQ, jmalinen-DlyHzToyqoxBDgjK7y7TUQ
In-Reply-To: <201107221958.23408.sshtylyov-hkdhdckH98+B+jHODAdFcQ@public.gmane.org>
On 07/22/2011 11:58 AM, Sergei Shtylyov wrote:
> The driver reads PCI subsystem ID from the PCI configuration register while it's
> already stored by the PCI subsystem in the 'subsystem_device' field of 'struct
> pci_dev'...
>
> Signed-off-by: Sergei Shtylyov<sshtylyov-hkdhdckH98+B+jHODAdFcQ@public.gmane.org>
subsysid doesn't appear to be used anywhere. It can be removed easily.
The patch will be sent separately.
--
Regards,
Pavel Roskin
--
To unsubscribe from this list: send the line "unsubscribe linux-wireless" in
the body of a message to majordomo-u79uwXL29TY76Z2rM5mHXA@public.gmane.org
More majordomo info at http://vger.kernel.org/majordomo-info.html
^ permalink raw reply
* [PATCH] bnad: remove duplicated #include
From: Huang Weiyi @ 2011-07-23 8:19 UTC (permalink / raw)
To: davem; +Cc: netdev, Huang Weiyi
Remove duplicated #include('s) in
drivers/net/bna/bnad.c
Signed-off-by: Huang Weiyi <weiyi.huang@gmail.com>
---
drivers/net/bna/bnad.c | 1 -
1 files changed, 0 insertions(+), 1 deletions(-)
diff --git a/drivers/net/bna/bnad.c b/drivers/net/bna/bnad.c
index c89c9b2..b7e80ac 100644
--- a/drivers/net/bna/bnad.c
+++ b/drivers/net/bna/bnad.c
@@ -25,7 +25,6 @@
#include <linux/if_ether.h>
#include <linux/ip.h>
#include <linux/prefetch.h>
-#include <linux/if_vlan.h>
#include "bnad.h"
#include "bna.h"
--
1.5.6.4
^ permalink raw reply related
* [PATCH] can: c_can: remove duplicated #include
From: Huang Weiyi @ 2011-07-23 8:19 UTC (permalink / raw)
To: davem; +Cc: netdev, Huang Weiyi
Remove duplicated #include('s) in
drivers/net/can/c_can/c_can.c
drivers/net/can/c_can/c_can_platform.c
Signed-off-by: Huang Weiyi <weiyi.huang@gmail.com>
---
drivers/net/can/c_can/c_can.c | 1 -
drivers/net/can/c_can/c_can_platform.c | 1 -
2 files changed, 0 insertions(+), 2 deletions(-)
diff --git a/drivers/net/can/c_can/c_can.c b/drivers/net/can/c_can/c_can.c
index 80adc83..536bda0 100644
--- a/drivers/net/can/c_can/c_can.c
+++ b/drivers/net/can/c_can/c_can.c
@@ -33,7 +33,6 @@
#include <linux/if_arp.h>
#include <linux/if_ether.h>
#include <linux/list.h>
-#include <linux/delay.h>
#include <linux/io.h>
#include <linux/can.h>
diff --git a/drivers/net/can/c_can/c_can_platform.c b/drivers/net/can/c_can/c_can_platform.c
index 0e300cf..0b5c6f8 100644
--- a/drivers/net/can/c_can/c_can_platform.c
+++ b/drivers/net/can/c_can/c_can_platform.c
@@ -27,7 +27,6 @@
#include <linux/if_arp.h>
#include <linux/if_ether.h>
#include <linux/list.h>
-#include <linux/delay.h>
#include <linux/io.h>
#include <linux/platform_device.h>
#include <linux/clk.h>
--
1.5.6.4
^ permalink raw reply related
* [PATCH] igb: remove duplicated #include
From: Huang Weiyi @ 2011-07-23 8:20 UTC (permalink / raw)
To: jeffrey.t.kirsher; +Cc: netdev, Huang Weiyi
Remove duplicated #include('s) in
drivers/net/igb/igb_main.c
Signed-off-by: Huang Weiyi <weiyi.huang@gmail.com>
---
drivers/net/igb/igb_main.c | 1 -
1 files changed, 0 insertions(+), 1 deletions(-)
diff --git a/drivers/net/igb/igb_main.c b/drivers/net/igb/igb_main.c
index cb8c6bb..dc59905 100644
--- a/drivers/net/igb/igb_main.c
+++ b/drivers/net/igb/igb_main.c
@@ -47,7 +47,6 @@
#include <linux/if_ether.h>
#include <linux/aer.h>
#include <linux/prefetch.h>
-#include <linux/if_vlan.h>
#ifdef CONFIG_IGB_DCA
#include <linux/dca.h>
#endif
--
1.5.6.4
^ permalink raw reply related
* [PATCH] qlge: remove duplicated #include
From: Huang Weiyi @ 2011-07-23 8:20 UTC (permalink / raw)
To: linux-driver; +Cc: netdev, Huang Weiyi
Remove duplicated #include('s) in
drivers/net/qlge/qlge_main.c
Signed-off-by: Huang Weiyi <weiyi.huang@gmail.com>
---
drivers/net/qlge/qlge_main.c | 1 -
1 files changed, 0 insertions(+), 1 deletions(-)
diff --git a/drivers/net/qlge/qlge_main.c b/drivers/net/qlge/qlge_main.c
index 743e3ec..f07e96e 100644
--- a/drivers/net/qlge/qlge_main.c
+++ b/drivers/net/qlge/qlge_main.c
@@ -36,7 +36,6 @@
#include <linux/ethtool.h>
#include <linux/if_vlan.h>
#include <linux/skbuff.h>
-#include <linux/if_vlan.h>
#include <linux/delay.h>
#include <linux/mm.h>
#include <linux/vmalloc.h>
--
1.5.6.4
^ permalink raw reply related
* [PATCH] via-velocity: remove duplicated #include
From: Huang Weiyi @ 2011-07-23 8:20 UTC (permalink / raw)
To: davem; +Cc: netdev, Huang Weiyi
Remove duplicated #include('s) in
drivers/net/via-velocity.c
Signed-off-by: Huang Weiyi <weiyi.huang@gmail.com>
---
drivers/net/via-velocity.c | 1 -
1 files changed, 0 insertions(+), 1 deletions(-)
diff --git a/drivers/net/via-velocity.c b/drivers/net/via-velocity.c
index a9aa4a3..deb1eca 100644
--- a/drivers/net/via-velocity.c
+++ b/drivers/net/via-velocity.c
@@ -77,7 +77,6 @@
#include <linux/udp.h>
#include <linux/crc-ccitt.h>
#include <linux/crc32.h>
-#include <linux/if_vlan.h>
#include "via-velocity.h"
--
1.5.6.4
^ permalink raw reply related
* Re: [PATCH] igb: remove duplicated #include
From: Jeff Kirsher @ 2011-07-23 8:24 UTC (permalink / raw)
To: Huang Weiyi; +Cc: netdev@vger.kernel.org
In-Reply-To: <1311409201-2324-1-git-send-email-weiyi.huang@gmail.com>
[-- Attachment #1: Type: text/plain, Size: 726 bytes --]
On Sat, 2011-07-23 at 01:20 -0700, Huang Weiyi wrote:
> Remove duplicated #include('s) in
> drivers/net/igb/igb_main.c
>
> Signed-off-by: Huang Weiyi <weiyi.huang@gmail.com>
> ---
> drivers/net/igb/igb_main.c | 1 -
> 1 files changed, 0 insertions(+), 1 deletions(-)
>
> diff --git a/drivers/net/igb/igb_main.c b/drivers/net/igb/igb_main.c
> index cb8c6bb..dc59905 100644
> --- a/drivers/net/igb/igb_main.c
> +++ b/drivers/net/igb/igb_main.c
> @@ -47,7 +47,6 @@
> #include <linux/if_ether.h>
> #include <linux/aer.h>
> #include <linux/prefetch.h>
> -#include <linux/if_vlan.h>
> #ifdef CONFIG_IGB_DCA
> #include <linux/dca.h>
> #endif
Acked-by: Jeff Kirsher <jeffrey.t.kirsher@intel.com>
[-- Attachment #2: This is a digitally signed message part --]
[-- Type: application/pgp-signature, Size: 490 bytes --]
^ permalink raw reply
* Re: [PATCH net-2.6 v2] gre: fix improper error handling
From: Eric Dumazet @ 2011-07-23 8:32 UTC (permalink / raw)
To: xeb; +Cc: davem, netdev
In-Reply-To: <201107231049.40603.xeb@mail.ru>
Le samedi 23 juillet 2011 à 10:49 +0400, xeb@mail.ru a écrit :
> Fix improper protocol err_handler, current implementation is fully
> unapplicable and may cause kernel crash due to double kfree_skb.
>
> Signed-off-by: Dmitry Kozlov <xeb@mail.ru>
> ---
> net/ipv4/gre.c | 21 ++++++---------------
> 1 files changed, 6 insertions(+), 15 deletions(-)
>
Good catch !
Acked-by: Eric Dumazet <eric.dumazet@gmail.com>
^ permalink raw reply
* write() udp socket
From: ZHOU Xiaobo @ 2011-07-23 9:29 UTC (permalink / raw)
To: netdev
question No1:
When I call
ssize_t write(int fd, const void *buf, size_t count);
on a nonblocking UDP socket, is the return value always equal to 'count'?
question No2:
Can I write() a UDP socket in multiple threads without locking?
thanks
------------------
Sincerely yours
ZHOU Xiaobo
^ permalink raw reply
* Transfer partnership
From: Transfer partnership @ 2011-07-23 10:01 UTC (permalink / raw)
[-- Attachment #1: Type: text/plain, Size: 18 bytes --]
OPEN ATTACH FILE.
[-- Attachment #2: Transfer partnership.docx --]
[-- Type: application/vnd.openxmlformats-officedocument.wordprocessingml.document, Size: 12528 bytes --]
^ permalink raw reply
* Re: [PATCH] net: Fix security_socket_sendmsg() bypass problem.
From: Tetsuo Handa @ 2011-07-23 10:39 UTC (permalink / raw)
To: mjt; +Cc: davem, casey, anton, netdev, linux-security-module
In-Reply-To: <4E2A7273.7030504@msgid.tls.msk.ru>
Michael Tokarev wrote:
> (I noticed samba.org address in the Cc list).
That's because Anton Blanchard is author of sendmmsg() system call.
> When I saw recvmmsg()/sendmmsg() here, my first thought was an
> authoritative DNS server which can read several requests at a
> time and answer them all at once too - this way it all will go
> to different addresses.
I don't know what application wants sendmmsg(). Since users can send up to
UIO_MAXIOV (= 1024) "struct iovec" blocks using sendmsg(), they will use
sendmsg() rather than sendmmsg() if the destination address are the same.
Therefore, I guess users will use sendmmsg() for sending to multiple different
destination addresses. If so, optimization based on destination address will do
more harm than benefit; simply passing nosec flag down to LSM modules (so that
SELinux will skip sock_has_perm() call and SMACK will not skip
smack_netlabel_send() call) will be sufficient for 3.0.x stable release.
Anton, how do you want to use sendmmsg()?
^ permalink raw reply
* [PATCH] ipv4: use RT_TOS after some rt_tos conversions
From: Julian Anastasov @ 2011-07-23 12:00 UTC (permalink / raw)
To: David S. Miller; +Cc: netdev
rt_tos was changed to iph->tos but it must be filtered by RT_TOS
Signed-off-by: Julian Anastasov <ja@ssi.bg>
---
diff -urp v3.0/linux/net/ipv4/ipmr.c linux/net/ipv4/ipmr.c
--- v3.0/linux/net/ipv4/ipmr.c 2011-07-23 14:35:17.551351207 +0300
+++ linux/net/ipv4/ipmr.c 2011-07-23 14:36:05.293350956 +0300
@@ -1796,7 +1796,7 @@ static struct mr_table *ipmr_rt_fib_look
struct flowi4 fl4 = {
.daddr = iph->daddr,
.saddr = iph->saddr,
- .flowi4_tos = iph->tos,
+ .flowi4_tos = RT_TOS(iph->tos),
.flowi4_oif = rt->rt_oif,
.flowi4_iif = rt->rt_iif,
.flowi4_mark = rt->rt_mark,
diff -urp v3.0/linux/net/ipv4/route.c linux/net/ipv4/route.c
--- v3.0/linux/net/ipv4/route.c 2011-07-23 14:35:17.183352539 +0300
+++ linux/net/ipv4/route.c 2011-07-23 14:36:18.488350045 +0300
@@ -1740,7 +1740,7 @@ void ip_rt_get_source(u8 *addr, struct s
memset(&fl4, 0, sizeof(fl4));
fl4.daddr = iph->daddr;
fl4.saddr = iph->saddr;
- fl4.flowi4_tos = iph->tos;
+ fl4.flowi4_tos = RT_TOS(iph->tos);
fl4.flowi4_oif = rt->dst.dev->ifindex;
fl4.flowi4_iif = skb->dev->ifindex;
fl4.flowi4_mark = skb->mark;
^ permalink raw reply
* Contact ming-yang3@live.com
From: Omar Said Ali Al Habsi @ 2011-07-23 12:13 UTC (permalink / raw)
I am Mr. Ming Yang,I have an obscured business suggestion for you.Your services will be paid for.Contact ming-yang3@live.com
^ permalink raw reply
* Your Mail Quota Has Exceeded The Set Quota
From: System Administrator @ 2011-07-23 14:02 UTC (permalink / raw)
Your Mail Quota Has Exceeded The Set Quota/Limit. You Are Currently
Running On 23GB Due To Hidden Files And Folder On Your Mailbox,
you may not be able to receive or send new mails until you re-validate.
Please Click the Link Below To Validate Your Mailbox And Increase Your Quota.
http://buzurl.com/ao70
Failure To Validate Your Quota May Result In Loss Of Important Information
In Your Mailbox Or Cause Limited Access To It.
Mail Quota alert -Error Code #1997142DDE
System Administrator
192.168.0.1
----------------------------------------------------------------
This message was sent using IMP, the Internet Messaging Program.
^ permalink raw reply
* Re: IPv6: autoconfiguration and suspend/resume or link down/up
From: Nicolas de Pesloüan @ 2011-07-23 14:31 UTC (permalink / raw)
To: Herbert Xu; +Cc: David Miller, jbohac, netdev, shemminger
In-Reply-To: <20110722092159.GA20722@gondor.apana.org.au>
Le 22/07/2011 11:21, Herbert Xu a écrit :
> On Fri, Jul 22, 2011 at 01:06:28AM -0700, David Miller wrote:
>>
>> Suspend is even more important because while we were suspended we
>> could be on the same network but the routers present and available
>> might have changed completely.
>
> Unfortunately virtual machine live migration also uses the suspend
> & resume mechanism. In that case we don't wish to renegotiate
> everything, since the goal is to minimise the outage window.
>
> This would suggest that putting the policy in user-space may be the
> best option.
For the particular situation where we use suspend/resume to migrate a virtual machine, we might have
a kernel parameter or sysfs entry that instruct the kernel not to renegotiate anything on resume.
That being said, the time to renegotiate a network setup sounds very short, compared to the time for
a full suspend-migrate-resume cycle. I'm not sure VM migration would really suffer from such
renegotiation.
And because the local network may change while we migrate the VM (in particular if the migration
happens because of some failover), I think we should enforce renegotiation on resume anyway.
Nicolas.
^ permalink raw reply
page: next (older) | prev (newer) | latest
- recent:[subjects (threaded)|topics (new)|topics (active)]
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
--- linux-3.0.orig/net/socket.c
+++ linux-3.0/net/socket.c
@@ -1871,8 +1871,19 @@ SYSCALL_DEFINE2(shutdown, int, fd, int,
#define COMPAT_NAMELEN(msg) COMPAT_MSG(msg, msg_namelen)
#define COMPAT_FLAGS(msg) COMPAT_MSG(msg, msg_flags)
+/*
+ * Structure for remembering destination's address used by send_mmsg().
+ * This is for calling security_socket_sendms() only once for each destination.
+ */
+struct sendmmsg_dest_info {
+ struct list_head list;
+ unsigned int address_len;
+ struct sockaddr_storage address;
+};
+
static int __sys_sendmsg(struct socket *sock, struct msghdr __user *msg,
- struct msghdr *msg_sys, unsigned flags, int nosec)
+ struct msghdr *msg_sys, unsigned flags,
+ struct list_head *list)
{
struct compat_msghdr __user *msg_compat =
(struct compat_msghdr __user *)msg;
@@ -1883,6 +1894,7 @@ static int __sys_sendmsg(struct socket *
/* 20 is size of ipv6_pktinfo */
unsigned char *ctl_buf = ctl;
int err, ctl_len, iov_size, total_len;
+ bool nosec = false;
err = -EFAULT;
if (MSG_CMSG_COMPAT & flags) {
@@ -1953,6 +1965,58 @@ static int __sys_sendmsg(struct socket *
if (sock->file->f_flags & O_NONBLOCK)
msg_sys->msg_flags |= MSG_DONTWAIT;
+ if (list) {
+ /*
+ * We need to pass destination address to
+ * security_socket_sendmsg() since some LSM modules want it.
+ * But passing already-checked destination address twice is
+ * waste of time.
+ *
+ * Therefore, check for already-checked destination address in
+ * order to see whether we can omit security_socket_sendmsg()
+ * call or not.
+ *
+ * This optimization assumes that LSM modules use only
+ * destination address (i.e. "struct msghdr"->msg_name and
+ * "struct msghdr"->msg_namelen). We can't use this assumption
+ * if LSM modules want to use other factors (e.g. total_len
+ * argument below).
+ */
+ struct sendmmsg_dest_info *ptr;
+ list_for_each_entry(ptr, list, list) {
+ /*
+ * verify_iovec()/verify_compat_iovec() above assigned
+ * appropriate values to msg_sys->msg_namelen and
+ * msg_sys->msg_name.
+ */
+ if (ptr->address_len != msg_sys->msg_namelen ||
+ memcmp(&ptr->address, msg_sys->msg_name,
+ ptr->address_len))
+ continue;
+ nosec = true;
+ break;
+ }
+ if (!nosec) {
+ /*
+ * Remember the destination address passed to
+ * sendmmsg() so that we can avoid calling
+ * security_sendmsg_permission() again for
+ * already-checked destination address.
+ *
+ * Out of memory error is not fatal here because
+ * calling security_sendmsg_permission() again for
+ * already-checked destination address should be
+ * harmless.
+ */
+ ptr = kmalloc(sizeof(*ptr), GFP_KERNEL);
+ if (ptr) {
+ ptr->address_len = msg_sys->msg_namelen;
+ memcpy(&ptr->address, msg_sys->msg_name,
+ ptr->address_len);
+ list_add(&ptr->list, list);
+ }
+ }
+ }
err = (nosec ? sock_sendmsg_nosec : sock_sendmsg)(sock, msg_sys,
total_len);
@@ -1979,7 +2043,7 @@ SYSCALL_DEFINE3(sendmsg, int, fd, struct
if (!sock)
goto out;
- err = __sys_sendmsg(sock, msg, &msg_sys, flags, 0);
+ err = __sys_sendmsg(sock, msg, &msg_sys, flags, NULL);
fput_light(sock->file, fput_needed);
out:
@@ -1998,6 +2062,7 @@ int __sys_sendmmsg(int fd, struct mmsghd
struct mmsghdr __user *entry;
struct compat_mmsghdr __user *compat_entry;
struct msghdr msg_sys;
+ LIST_HEAD(list); /* List for finding duplicated destination address. */
datagrams = 0;
@@ -2014,18 +2079,19 @@ int __sys_sendmmsg(int fd, struct mmsghd
while (datagrams < vlen) {
/*
* No need to ask LSM for more than the first datagram.
*/
if (MSG_CMSG_COMPAT & flags) {
err = __sys_sendmsg(sock, (struct msghdr __user *)compat_entry,
- &msg_sys, flags, datagrams);
+ &msg_sys, flags, &list);
if (err < 0)
break;
err = __put_user(err, &compat_entry->msg_len);
++compat_entry;
} else {
err = __sys_sendmsg(sock, (struct msghdr __user *)entry,
- &msg_sys, flags, datagrams);
+ &msg_sys, flags, &list);
if (err < 0)
break;
err = put_user(err, &entry->msg_len);
@@ -2038,6 +2104,14 @@ int __sys_sendmmsg(int fd, struct mmsghd
}
out_put:
+ { /* Clean up destination addresses. */
+ struct sendmmsg_dest_info *ptr;
+ struct sendmmsg_dest_info *tmp;
+ list_for_each_entry_safe(ptr, tmp, &list, list) {
+ list_del(&ptr->list);
+ kfree(ptr);
+ }
+ }
fput_light(sock->file, fput_needed);
if (err == 0)
^ permalink raw reply
* [PATCH net-2.6 v2] gre: fix improper error handling
From: xeb @ 2011-07-23 6:49 UTC (permalink / raw)
To: davem; +Cc: netdev
[-- Attachment #1: Type: text/plain, Size: 180 bytes --]
Fix improper protocol err_handler, current implementation is fully
unapplicable and may cause kernel crash due to double kfree_skb.
Signed-off-by: Dmitry Kozlov <xeb@mail.ru>
---
[-- Attachment #2: patch --]
[-- Type: text/plain, Size: 1156 bytes --]
net/ipv4/gre.c | 21 ++++++---------------
@@ -2014,18 +2079,19 @@ int __sys_sendmmsg(int fd, struct mmsghd
while (datagrams < vlen) {
/*
- * No need to ask LSM for more than the first datagram.
+ * No need to ask LSM for more than the first datagram for
+ * each destination.
*/
if (MSG_CMSG_COMPAT & flags) {
1 files changed, 6 insertions(+), 15 deletions(-)